@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminGenericInterfaceOperationDefault.pm - provides a log view for admins
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminGenericInterfaceOperationDefault.pm,v 1.8.2.1 2012/09/24 23:30:29 cr Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::Modules::AdminGenericInterfaceOperationDefault;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.8.2.1 $) [1];
-
 use Kernel::System::GenericInterface::Webservice;
 
 use Kernel::System::VariableCheck qw(:all);
@@ -190,13 +185,12 @@ sub _AddAction {
     }
 
     my $Config = {
-        Type => $GetParam{OperationType},
+        Type        => $GetParam{OperationType},
         Description => $Self->{ParamObject}->GetParam( Param => 'Description' ) || '',
     };
 
     my $MappingInbound = $Self->{ParamObject}->GetParam( Param => 'MappingInbound' );
-    $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
+    $MappingInbound = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
 
     if ($MappingInbound) {
         $Config->{MappingInbound} = {
@@ -205,8 +199,7 @@ sub _AddAction {
     }
 
     my $MappingOutbound = $Self->{ParamObject}->GetParam( Param => 'MappingOutbound' );
-    $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
+    $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
 
     if ($MappingOutbound) {
         $Config->{MappingOutbound} = {
@@ -224,8 +217,7 @@ sub _AddAction {
         );
     }
 
-    my $RedirectURL
-        = "Action=AdminGenericInterfaceOperationDefault;Subaction=Change;WebserviceID=$WebserviceID;";
+    my $RedirectURL = "Action=AdminGenericInterfaceOperationDefault;Subaction=Change;WebserviceID=$WebserviceID;";
     $RedirectURL
         .= 'Operation=' . $Self->{LayoutObject}->LinkEncode( $GetParam{Operation} ) . ';';
 
@@ -249,9 +241,9 @@ sub _Change {
     }
 
     if (
-        ref $WebserviceData->{Config}                                           ne 'HASH'
-        || ref $WebserviceData->{Config}->{Provider}                            ne 'HASH'
-        || ref $WebserviceData->{Config}->{Provider}->{Operation}               ne 'HASH'
+        ref $WebserviceData->{Config} ne 'HASH'
+        || ref $WebserviceData->{Config}->{Provider} ne 'HASH'
+        || ref $WebserviceData->{Config}->{Provider}->{Operation} ne 'HASH'
         || ref $WebserviceData->{Config}->{Provider}->{Operation}->{$Operation} ne 'HASH'
         )
     {
@@ -297,8 +289,8 @@ sub _ChangeAction {
 
     # Get config data of existing operation.
     if (
-        ref $WebserviceData->{Config}                             ne 'HASH'
-        || ref $WebserviceData->{Config}->{Provider}              ne 'HASH'
+        ref $WebserviceData->{Config} ne 'HASH'
+        || ref $WebserviceData->{Config}->{Provider} ne 'HASH'
         || ref $WebserviceData->{Config}->{Provider}->{Operation} ne 'HASH'
         || ref $WebserviceData->{Config}->{Provider}->{Operation}->{ $GetParam{OldOperation} } ne
         'HASH'
@@ -309,8 +301,7 @@ sub _ChangeAction {
         );
     }
 
-    my $OperationConfig
-        = $WebserviceData->{Config}->{Provider}->{Operation}->{ $GetParam{OldOperation} };
+    my $OperationConfig = $WebserviceData->{Config}->{Provider}->{Operation}->{ $GetParam{OldOperation} };
 
     # Operation was renamed, avoid conflicts
     if ( $GetParam{OldOperation} ne $GetParam{Operation} ) {
@@ -345,8 +336,7 @@ sub _ChangeAction {
 
     # Now handle mappings. If mapping types were not changed, keep the mapping configuration.
     my $MappingInbound = $Self->{ParamObject}->GetParam( Param => 'MappingInbound' );
-    $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
+    $MappingInbound = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
 
     # No inbound mapping set, make sure it is not present in the configuration.
     if ( !$MappingInbound ) {
@@ -362,8 +352,7 @@ sub _ChangeAction {
     }
 
     my $MappingOutbound = $Self->{ParamObject}->GetParam( Param => 'MappingOutbound' );
-    $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
+    $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
 
     # No outbound mapping set, make sure it is not present in the configuration.
     if ( !$MappingOutbound ) {
@@ -396,8 +385,7 @@ sub _ChangeAction {
 
     # Save and finish button: go to Webservice.
     if ( $Self->{ParamObject}->GetParam( Param => 'ReturnToWebservice' ) ) {
-        $RedirectURL
-            = "Action=AdminGenericInterfaceWebservice;Subaction=Change;WebserviceID=$WebserviceID;";
+        $RedirectURL = "Action=AdminGenericInterfaceWebservice;Subaction=Change;WebserviceID=$WebserviceID;";
 
     }
 
@@ -490,8 +478,7 @@ sub _ShowScreen {
     # Inbound mapping
     my @MappingList = sort keys %{$Mappings};
 
-    my $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $Param{MappingInbound} )
+    my $MappingInbound = $Self->_MappingTypeCheck( MappingType => $Param{MappingInbound} )
         ? $Param{MappingInbound}
         : '';
 
@@ -519,8 +506,7 @@ sub _ShowScreen {
     }
 
     # Outbound mapping
-    my $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $Param{MappingOutbound} )
+    my $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $Param{MappingOutbound} )
         ? $Param{MappingOutbound}
         : '';
 
