@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AdminPGP.pm - to add/update/delete pgp keys
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -85,7 +85,9 @@ sub Run {
         my $Key  = $Self->{ParamObject}->GetParam( Param => 'Key' )  || '';
         my $Type = $Self->{ParamObject}->GetParam( Param => 'Type' ) || '';
         if ( !$Key ) {
-            return $Self->{LayoutObject}->ErrorScreen( Message => 'Need param Key to delete!', );
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => 'Need param Key to delete!',
+            );
         }
         my $Success = '';
         if ( $Type eq 'sec' ) {
@@ -123,7 +125,10 @@ sub Run {
         }
         $Output .= $Self->{LayoutObject}->Notify( Info => $Message );
 
-        $Output .= $Self->{LayoutObject}->Output( TemplateFile => 'AdminPGP', Data => \%Param );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminPGP',
+            Data         => \%Param
+        );
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
@@ -161,8 +166,7 @@ sub Run {
             Value     => '',
         );
         my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
-            Param  => 'FileUpload',
-            Source => 'String',
+            Param => 'FileUpload',
         );
         if ( !%UploadStuff ) {
             $Errors{FileUploadInvalid} = 'ServerError';
@@ -234,7 +238,9 @@ sub Run {
         my $Key  = $Self->{ParamObject}->GetParam( Param => 'Key' )  || '';
         my $Type = $Self->{ParamObject}->GetParam( Param => 'Type' ) || '';
         if ( !$Key ) {
-            return $Self->{LayoutObject}->ErrorScreen( Message => 'Need param Key to download!', );
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => 'Need param Key to download!',
+            );
         }
         my $KeyString = '';
         if ( $Type eq 'sec' ) {
@@ -262,7 +268,9 @@ sub Run {
         my $Key  = $Self->{ParamObject}->GetParam( Param => 'Key' )  || '';
         my $Type = $Self->{ParamObject}->GetParam( Param => 'Type' ) || '';
         if ( !$Key ) {
-            return $Self->{LayoutObject}->ErrorScreen( Message => 'Need param Key to download!', );
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => 'Need param Key to download!',
+            );
         }
         my $Download = '';
         if ( $Type eq 'sec' ) {
@@ -290,6 +298,19 @@ sub Run {
     # ------------------------------------------------------------ #
     else {
 
+        my $Output .= $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+
+        if ( !$Self->{CryptObject} && $Self->{ConfigObject}->Get('PGP') ) {
+            $Output .= $Self->{LayoutObject}->Notify(
+                Priority => 'Error',
+                Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( "Cannot create %s!", "CryptObject" ),
+                Link =>
+                    $Self->{LayoutObject}->{Baselink}
+                    . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::PGP',
+            );
+        }
+
         $Self->{LayoutObject}->Block( Name => 'Overview' );
         $Self->{LayoutObject}->Block( Name => 'ActionList' );
         $Self->{LayoutObject}->Block( Name => 'ActionSearch' );
@@ -315,15 +336,17 @@ sub Run {
                 Data => {},
             );
         }
-        my $Output .= $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-        if ( $Self->{CryptObject}->Check() ) {
+
+        if ( $Self->{CryptObject} && $Self->{CryptObject}->Check() ) {
             $Output .= $Self->{LayoutObject}->Notify(
                 Priority => 'Error',
-                Data     => '$Text{"' . $Self->{CryptObject}->Check() . '"}',
+                Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( $Self->{CryptObject}->Check() ),
             );
         }
-        $Output .= $Self->{LayoutObject}->Output( TemplateFile => 'AdminPGP', Data => \%Param );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'AdminPGP',
+            Data         => \%Param
+        );
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
