@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminProcessManagementTransition.pm - process management transition
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: AdminProcessManagementTransition.pm,v 1.17 2013/02/14 10:28:28 mg Exp $
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,9 +20,6 @@ use Kernel::System::ProcessManagement::DB::Transition;
 
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.17 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -43,12 +38,11 @@ sub new {
     }
 
     # create additional objects
-    $Self->{JSONObject}     = Kernel::System::JSON->new( %{$Self} );
-    $Self->{ProcessObject}  = Kernel::System::ProcessManagement::DB::Process->new( %{$Self} );
-    $Self->{EntityObject}   = Kernel::System::ProcessManagement::DB::Entity->new( %{$Self} );
-    $Self->{ActivityObject} = Kernel::System::ProcessManagement::DB::Activity->new( %{$Self} );
-    $Self->{TransitionObject}
-        = Kernel::System::ProcessManagement::DB::Transition->new( %{$Self} );
+    $Self->{JSONObject}       = Kernel::System::JSON->new( %{$Self} );
+    $Self->{ProcessObject}    = Kernel::System::ProcessManagement::DB::Process->new( %{$Self} );
+    $Self->{EntityObject}     = Kernel::System::ProcessManagement::DB::Entity->new( %{$Self} );
+    $Self->{ActivityObject}   = Kernel::System::ProcessManagement::DB::Activity->new( %{$Self} );
+    $Self->{TransitionObject} = Kernel::System::ProcessManagement::DB::Transition->new( %{$Self} );
 
     return $Self;
 }
@@ -93,7 +87,7 @@ sub Run {
         my $TransitionData;
 
         # get parameter from web browser
-        my $GetParam = $Self->_GetParams;
+        my $GetParam = $Self->_GetParams();
 
         # set new configuration
         $TransitionData->{Name}   = $GetParam->{Name};
@@ -146,7 +140,7 @@ sub Run {
             );
         }
 
-        # set entitty sync state
+        # set entity sync state
         my $Success = $Self->{EntityObject}->EntitySyncStateSet(
             EntityType => 'Transition',
             EntityID   => $EntityID,
@@ -183,13 +177,10 @@ sub Run {
                 Subaction => 'TransitionEdit'    # always use edit screen
             );
 
-            my $RedirectAction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' ) || '';
-            my $RedirectSubaction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
-            my $RedirectID = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' ) || '';
-            my $RedirectEntityID
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' ) || '';
+            my $RedirectAction    = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' )    || '';
+            my $RedirectSubaction = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
+            my $RedirectID        = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' )        || '';
+            my $RedirectEntityID  = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' )  || '';
 
             # redirect to another popup window
             return $Self->_PopupResponse(
@@ -278,7 +269,7 @@ sub Run {
         my $TransitionData;
 
         # get parameter from web browser
-        my $GetParam = $Self->_GetParams;
+        my $GetParam = $Self->_GetParams();
 
         # set new configuration
         $TransitionData->{Name}     = $GetParam->{Name};
@@ -320,7 +311,7 @@ sub Run {
             );
         }
 
-        # set entitty sync state
+        # set entity sync state
         $Success = $Self->{EntityObject}->EntitySyncStateSet(
             EntityType => 'Transition',
             EntityID   => $EntityID,
@@ -357,13 +348,10 @@ sub Run {
                 Subaction => 'TransitionEdit'               # always use edit screen
             );
 
-            my $RedirectAction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' ) || '';
-            my $RedirectSubaction
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
-            my $RedirectID = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' ) || '';
-            my $RedirectEntityID
-                = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' ) || '';
+            my $RedirectAction    = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectAction' )    || '';
+            my $RedirectSubaction = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectSubaction' ) || '';
+            my $RedirectID        = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectID' )        || '';
+            my $RedirectEntityID  = $Self->{ParamObject}->GetParam( Param => 'PopupRedirectEntityID' )  || '';
 
             # redirect to another popup window
             return $Self->_PopupResponse(
@@ -436,8 +424,7 @@ sub _GetTransitionConfig {
 
     my %TransitionConfig;
     $TransitionConfig{Transition} = ();
-    $TransitionConfig{Transition}->{ $Param{EntityID} }
-        = $ProcessDump->{Transition}->{ $Param{EntityID} };
+    $TransitionConfig{Transition}->{ $Param{EntityID} } = $ProcessDump->{Transition}->{ $Param{EntityID} };
 
     return \%TransitionConfig;
 }
@@ -485,9 +472,9 @@ sub _ShowEdit {
     );
 
     $Param{FreshConditionLinking} = $Self->{LayoutObject}->BuildSelection(
-        Data => [ 'and', 'or', 'xor' ],
-        Name => "ConditionLinking[_INDEX_]",
-        Sort => 'AlphanumericKey',
+        Data        => [ 'and', 'or', 'xor' ],
+        Name        => "ConditionLinking[_INDEX_]",
+        Sort        => 'AlphanumericKey',
         Translation => 1,
         Class       => 'W50pc',
     );
@@ -496,10 +483,10 @@ sub _ShowEdit {
         Data => {
             'String' => 'String',
 
-# disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
-# TODO: implement a possibility to enter the data in a correct way in the GUI
-#'Hash'   => 'Hash',
-#'Array'  => 'Array',
+          # disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
+          # TODO: implement a possibility to enter the data in a correct way in the GUI
+          #'Hash'   => 'Hash',
+          #'Array'  => 'Array',
             'Regexp' => 'Regexp',
             'Module' => 'Transition Validation Module'
         },
@@ -512,13 +499,13 @@ sub _ShowEdit {
     if ( defined $Param{Action} && $Param{Action} eq 'Edit' ) {
 
         $Param{OverallConditionLinking} = $Self->{LayoutObject}->BuildSelection(
-            Data => [ 'and', 'or', 'xor' ],
-            Name => 'OverallConditionLinking',
-            ID   => 'OverallConditionLinking',
-            Sort => 'AlphanumericKey',
-            Translation   => 1,
-            Class         => 'W50pc',
-            SelectedValue => $TransitionData->{Config}->{ConditionLinking},
+            Data        => [ 'and', 'or', 'xor' ],
+            Name        => 'OverallConditionLinking',
+            ID          => 'OverallConditionLinking',
+            Sort        => 'AlphanumericKey',
+            Translation => 1,
+            Class       => 'W50pc',
+            SelectedID  => $TransitionData->{Config}->{ConditionLinking},
         );
 
         my @Conditions = sort keys %{ $TransitionData->{Config}->{Condition} };
@@ -528,12 +515,12 @@ sub _ShowEdit {
             my %ConditionData = %{ $TransitionData->{Config}->{Condition}->{$Condition} };
 
             my $ConditionLinking = $Self->{LayoutObject}->BuildSelection(
-                Data => [ 'and', 'or', 'xor' ],
-                Name => "ConditionLinking[$Condition]",
-                Sort => 'AlphanumericKey',
-                Translation   => 1,
-                Class         => 'W50pc',
-                SelectedValue => $ConditionData{ConditionLinking},
+                Data        => [ 'and', 'or', 'xor' ],
+                Name        => "ConditionLinking[$Condition]",
+                Sort        => 'AlphanumericKey',
+                Translation => 1,
+                Class       => 'W50pc',
+                SelectedID  => $ConditionData{Type},
             );
 
             $Self->{LayoutObject}->Block(
@@ -552,17 +539,17 @@ sub _ShowEdit {
                     Data => {
                         'String' => 'String',
 
-# disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
-# TODO: implement a possibility to enter the data in a correct way in the GUI
-#'Hash'   => 'Hash',
-#'Array'  => 'Array',
+          # disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
+          # TODO: implement a possibility to enter the data in a correct way in the GUI
+          #'Hash'   => 'Hash',
+          #'Array'  => 'Array',
                         'Regexp' => 'Regexp',
                         'Module' => 'Transition Validation Module'
                     },
-                    Name          => "ConditionFieldType[$Condition][$Field]",
-                    Sort          => 'AlphanumericKey',
-                    Translation   => 1,
-                    SelectedValue => $FieldData{Type},
+                    Name        => "ConditionFieldType[$Condition][$Field]",
+                    Sort        => 'AlphanumericKey',
+                    Translation => 1,
+                    SelectedID  => $FieldData{Type},
                 );
 
                 # show fields
@@ -596,18 +583,18 @@ sub _ShowEdit {
     else {
 
         $Param{OverallConditionLinking} = $Self->{LayoutObject}->BuildSelection(
-            Data => [ 'and', 'or', 'xor' ],
-            Name => 'OverallConditionLinking',
-            ID   => 'OverallConditionLinking',
-            Sort => 'AlphanumericKey',
+            Data        => [ 'and', 'or', 'xor' ],
+            Name        => 'OverallConditionLinking',
+            ID          => 'OverallConditionLinking',
+            Sort        => 'AlphanumericKey',
             Translation => 1,
             Class       => 'W50pc',
         );
 
         $Param{ConditionLinking} = $Self->{LayoutObject}->BuildSelection(
-            Data => [ 'and', 'or', 'xor' ],
-            Name => 'ConditionLinking[_INDEX_]',
-            Sort => 'AlphanumericKey',
+            Data        => [ 'and', 'or', 'xor' ],
+            Name        => 'ConditionLinking[_INDEX_]',
+            Sort        => 'AlphanumericKey',
             Translation => 1,
             Class       => 'W50pc',
         );
@@ -616,10 +603,10 @@ sub _ShowEdit {
             Data => {
                 'String' => 'String',
 
-# disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
-# TODO: implement a possibility to enter the data in a correct way in the GUI
-#'Hash'   => 'Hash',
-#'Array'  => 'Array',
+          # disable hash and array selection here, because there is no practical way to enter the needed data in the GUI
+          # TODO: implement a possibility to enter the data in a correct way in the GUI
+          #'Hash'   => 'Hash',
+          #'Array'  => 'Array',
                 'Regexp' => 'Regexp',
                 'Module' => 'Transition Validation Module'
             },
