@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Kernel/Modules/AdminRegistration.pm - to register the OTRS system
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,9 +14,8 @@ use warnings;
 
 use Kernel::System::Environment;
 use Kernel::System::Registration;
-use Kernel::System::SysConfig;
 use Kernel::System::SystemData;
-use Kernel::System::PID;
+use Kernel::System::OTRSBusiness;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -32,9 +32,8 @@ sub new {
     }
     $Self->{EnvironmentObject}  = Kernel::System::Environment->new(%Param);
     $Self->{RegistrationObject} = Kernel::System::Registration->new(%Param);
-    $Self->{SysConfigObject}    = Kernel::System::SysConfig->new(%Param);
     $Self->{SystemDataObject}   = Kernel::System::SystemData->new(%Param);
-    $Self->{PIDObject}          = Kernel::System::PID->new(%Param);
+    $Self->{OTRSBusinessObject} = Kernel::System::OTRSBusiness->new(%Param);
 
     $Self->{RegistrationState} = $Self->{SystemDataObject}->SystemDataGet(
         Key => 'Registration::State',
@@ -57,41 +56,11 @@ sub Run {
         }
     }
 
-    # ------------------------------------------------------------ #
-    # Scheduler not running screen
-    # ------------------------------------------------------------ #
-    if (
-        $Self->{Subaction} ne 'OTRSIDValidate'
-        && $Self->{RegistrationState} ne 'registered'
-        && !$Self->_SchedulerRunning()
-        )
-    {
-
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
-
-        $Self->{LayoutObject}->Block(
-            Name => 'Overview',
-            Data => \%Param,
-        );
-
-        $Self->{LayoutObject}->Block(
-            Name => 'SchedulerNotRunning',
-        );
-
-        $Output .= $Self->{LayoutObject}->Output(
-            TemplateFile => 'AdminRegistration',
-            Data         => \%Param,
-        );
-        $Output .= $Self->{LayoutObject}->Footer();
-
-        return $Output;
-    }
-
     # ------------------------------------------------------------ #
     # check OTRS ID
     # ------------------------------------------------------------ #
-    elsif ( $Self->{Subaction} eq 'CheckOTRSID' ) {
+
+    if ( $Self->{Subaction} eq 'CheckOTRSID' ) {
 
         my $OTRSID   = $Self->{ParamObject}->GetParam( Param => 'OTRSID' )   || '';
         my $Password = $Self->{ParamObject}->GetParam( Param => 'Password' ) || '';
@@ -137,11 +106,6 @@ sub Run {
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
-            Name => 'OTRSIDValidationForm',
-            Data => \%Param,
-        );
-
         my $Block = $Self->{RegistrationState} ne 'registered'
             ? 'OTRSIDRegistration'
             : 'OTRSIDDeregistration';
@@ -171,31 +135,36 @@ sub Run {
             Data => \%Param,
         );
 
-        $Self->{LayoutObject}->Block(
-            Name => 'OTRSIDValidation',
-            Data => \%Param,
+        my $EntitlementStatus = $Self->{OTRSBusinessObject}->OTRSBusinessEntitlementStatus(
+            CallCloudService => 1,
         );
 
-        my $Block = $Self->{RegistrationState} ne 'registered'
-            ? 'OTRSIDRegistration'
-            : 'OTRSIDDeregistration';
-        $Self->{LayoutObject}->Block(
-            Name => $Block,
-        );
+        # users should not be able to de-register their system if they either have
+        # OTRS Business Solution installed or are entitled to use it (by having a valid contract).
+        if ( $Self->{RegistrationState} eq 'registered'
+            && ( $Self->{OTRSBusinessObject}->OTRSBusinessIsInstalled() || $EntitlementStatus ne 'forbidden' ) )
+        {
 
-        # check if the scheduler is not running
-        if ( $Self->{RegistrationState} ne 'registered' && !$Self->_SchedulerRunning() ) {
+            $Self->{LayoutObject}->Block( Name => 'ActionList' );
+            $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
             $Self->{LayoutObject}->Block(
-                Name => 'OTRSIDValidationSchedulerNotRunning',
+                Name => 'OTRSIDDeregistrationNotPossible',
             );
         }
         else {
 
             $Self->{LayoutObject}->Block(
-                Name => 'OTRSIDValidationForm',
+                Name => 'OTRSIDValidation',
                 Data => \%Param,
             );
+
+            my $Block = $Self->{RegistrationState} ne 'registered'
+                ? 'OTRSIDRegistration'
+                : 'OTRSIDDeregistration';
+            $Self->{LayoutObject}->Block(
+                Name => $Block,
+            );
         }
 
         $Output .= $Self->{LayoutObject}->Output(
@@ -510,22 +479,4 @@ sub _Overview {
     return 1;
 }
 
-sub _SchedulerRunning {
-    my ( $Self, %Param ) = @_;
-
-    # try to get scheduler PID
-    my %PID = $Self->{PIDObject}->PIDGet(
-        Name => 'otrs.Scheduler',
-    );
-
-    my $PIDUpdateTime = $Self->{ConfigObject}->Get('Scheduler::PIDUpdateTime') || 600;
-
-    # check if scheduler process is registered in the DB and if the update was not too long ago
-    if ( !%PID || ( time() - $PID{Changed} > 4 * $PIDUpdateTime ) ) {
-        return;
-    }
-
-    return 1;
-}
-
 1;
