@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/Installer.pm - provides the DB installer
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -158,12 +158,12 @@ sub Run {
     }
 
     # print intro form
-    my $Title = $Self->{LayoutObject}->{LanguageObject}->Get('Install OTRS');
+    my $Title = $Self->{LayoutObject}->{LanguageObject}->Translate('Install OTRS');
     if ( $Self->{Subaction} eq 'Intro' ) {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Intro')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Intro')
             );
         $Self->{LayoutObject}->Block(
             Name => 'Intro',
@@ -182,7 +182,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('License')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('License')
             );
         $Self->{LayoutObject}->Block(
             Name => 'License',
@@ -209,7 +209,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Error')
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Error')
                 );
             $Output .= $Self->{LayoutObject}->Warning(
                 Message => "Kernel/Config.pm isn't writable!",
@@ -243,7 +243,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Database Selection')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Database Selection')
             );
         $Self->{LayoutObject}->Block(
             Name => 'DatabaseStart',
@@ -317,14 +317,14 @@ sub Run {
 
         if ( $DBType eq 'mysql' ) {
             my $PasswordExplanation = $DBInstallType eq 'CreateDB'
-                ? $Self->{LayoutObject}->{LanguageObject}->Get(
-                'If you have set a root password for your database, it must be entered here. If not, leave this field empty.'
+                ? $Self->{LayoutObject}->{LanguageObject}->Translate(
+                'If you have set a root password for your database, it must be entered here. If not, leave this field empty.',
                 )
-                : $Self->{LayoutObject}->{LanguageObject}->Get('Enter the password for the database user.');
+                : $Self->{LayoutObject}->{LanguageObject}->Translate('Enter the password for the database user.');
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' MySQL'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' MySQL'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseMySQL',
@@ -368,7 +368,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database')
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database')
                     . ' Microsoft SQL Server'
                 );
             $Self->{LayoutObject}->Block(
@@ -414,7 +414,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' PostgreSQL'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' PostgreSQL'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabasePostgreSQL',
@@ -454,7 +454,7 @@ sub Run {
             my $Output =
                 $Self->{LayoutObject}->Header(
                 Title => "$Title - "
-                    . $Self->{LayoutObject}->{LanguageObject}->Get('Database') . ' Oracle'
+                    . $Self->{LayoutObject}->{LanguageObject}->Translate('Database') . ' Oracle'
                 );
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseOracle',
@@ -513,7 +513,7 @@ sub Run {
 
         my $Output = $Self->{LayoutObject}->Header(
             Title => $Title . '-'
-                . $Self->{LayoutObject}->{LanguageObject}->Get(
+                . $Self->{LayoutObject}->{LanguageObject}->Translate(
                 'Create Database'
                 )
         );
@@ -598,8 +598,8 @@ sub Run {
         elsif ( $DB{DBType} eq 'oracle' ) {
 
             # set DSN for Config.pm
-            $DB{ConfigDSN} = 'DBI:Oracle:host=$Self->{DatabaseHost};' . "sid=$DB{DBSID};port=$DB{DBPort}";
-            $DB{DSN}       = "DBI:Oracle:host=$DB{DBHost};sid=$DB{DBSID};port=$DB{DBPort}";
+            $DB{ConfigDSN} = 'DBI:Oracle://$Self->{DatabaseHost}:' . $DB{DBPort} . '/' . $DB{DBSID};
+            $DB{DSN}       = "DBI:Oracle://$Self->{DBHost}:$DB{DBPort}/$Self->{DBSID}";
             $Self->{ConfigObject}->Set(
                 Key   => 'Database::Connect',
                 Value => "ALTER SESSION SET NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'",
@@ -816,7 +816,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('System Settings')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('System Settings')
             );
 
         $Self->{LayoutObject}->Block(
@@ -916,7 +916,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Configure Mail')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Configure Mail')
             );
         $Self->{LayoutObject}->Block(
             Name => 'ConfigureMail',
@@ -1017,7 +1017,7 @@ sub Run {
         my $Output =
             $Self->{LayoutObject}->Header(
             Title => "$Title - "
-                . $Self->{LayoutObject}->{LanguageObject}->Get('Finished')
+                . $Self->{LayoutObject}->{LanguageObject}->Translate('Finished')
             );
         $Self->{LayoutObject}->Block(
             Name => 'Finish',
