@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Notification.pm - lib for notifications
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +12,13 @@ package Kernel::System::Notification;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+);
+
 =head1 NAME
 
 Kernel::System::Notification - notification functions
@@ -28,41 +35,11 @@ This module is managing notifications.
 
 =item new()
 
-create a notification object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::Notification;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $NotificationObject = Kernel::System::Notification->new(
-        EncodeObject => $EncodeObject,
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-        DBObject     => $DBObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $NotificationObject = $Kernel::OM->Get('Kernel::System::Notification');
 
 =cut
 
@@ -73,13 +50,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject EncodeObject)) {
-        die "Got no $_!" if !$Param{$_};
-
-        $Self->{$_} = $Param{$_};
-    }
-
     return $Self;
 }
 
@@ -98,7 +68,7 @@ sub NotificationGet {
 
     # check needed stuff
     if ( !$Param{Name} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need Name!'
         );
@@ -107,7 +77,10 @@ sub NotificationGet {
 
     my ( $Language, $Type ) = $Param{Name} =~ m{^(.+?)::(.*)}smx;
 
-    $Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    $DBObject->Prepare(
         SQL => 'SELECT id, notification_type, notification_charset, '
             . ' notification_language, subject, text, content_type '
             . ' FROM notifications WHERE '
@@ -116,11 +89,14 @@ sub NotificationGet {
         Limit => 1,
     );
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     my %Data;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         # convert body
-        $Data[5] = $Self->{EncodeObject}->Convert(
+        $Data[5] = $EncodeObject->Convert(
             Text  => $Data[5],
             From  => $Data[2],
             To    => 'utf-8',
@@ -128,7 +104,7 @@ sub NotificationGet {
         );
 
         # convert subject
-        $Data[3] = $Self->{EncodeObject}->Convert(
+        $Data[3] = $EncodeObject->Convert(
             Text  => $Data[3],
             From  => $Data[2],
             To    => 'utf-8',
@@ -149,7 +125,9 @@ sub NotificationGet {
             ContentType => $Data[6] || 'text/plain',
         );
     }
+
     if ( !%Data && !$Param{Loop} ) {
+
         return $Self->NotificationGet(
             %Param,
             Name => 'en::' . $Type,
@@ -157,7 +135,8 @@ sub NotificationGet {
         );
     }
     elsif ( !%Data && $Param{Loop} ) {
-        $Self->{LogObject}->Log(
+
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Can't find notification for $Type and $Language!",
         );
@@ -178,21 +157,28 @@ get notification list
 sub NotificationList {
     my ( $Self, %Param ) = @_;
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # sql
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'SELECT id, notification_type, notification_charset, '
             . ' notification_language FROM notifications',
     );
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     # get languages
-    my %Languages = %{ $Self->{ConfigObject}->{DefaultUsedLanguages} };
+    my %Languages = %{ $ConfigObject->{DefaultUsedLanguages} };
 
     # get possible notification types
     my %Types;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    TYPE:
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         # do not use customer notifications this way anymore (done by notification event now)
-        next if $Data[1] =~ /Customer::(Owner|Queue|State)Update/;
+        next TYPE if $Data[1] =~ /Customer::(Owner|Queue|State)Update/;
         $Types{ $Data[1] } = 1;
     }
     for (qw(NewTicket FollowUp LockTimeout OwnerUpdate AddNote Move PendingReminder Escalation)) {
@@ -209,15 +195,16 @@ sub NotificationList {
     }
 
     # get real list
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'SELECT id, notification_type, notification_charset, '
             . ' notification_language FROM notifications',
     );
 
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    TYPE:
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         # do not use customer notifications this way anymore (done by notification event now)
-        next if $Data[1] =~ /Customer::(Owner|Queue|State)Update/;
+        next TYPE if $Data[1] =~ /Customer::(Owner|Queue|State)Update/;
 
         # remember list
         $List{ $Data[3] . '::' . $Data[1] } = $Data[3] . '::' . $Data[1];
@@ -247,7 +234,7 @@ sub NotificationUpdate {
     # check needed stuff
     for (qw(Type Charset Language Subject Body ContentType UserID)) {
         if ( !defined( $Param{$_} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -258,8 +245,11 @@ sub NotificationUpdate {
     # fix some bad stuff from some browsers (Opera)!
     $Param{Body} =~ s/(\n\r|\r\r\n|\r\n|\r)/\n/g;
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # sql
-    $Self->{DBObject}->Do(
+    $DBObject->Do(
         SQL => 'DELETE FROM notifications WHERE notification_type = ? '
             . 'AND notification_language = ?',
         Bind => [
@@ -268,7 +258,7 @@ sub NotificationUpdate {
     );
 
     # sql
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'INSERT INTO notifications '
             . '(notification_type, notification_charset, notification_language, subject, text, '
             . 'content_type, create_time, create_by, change_time, change_by) '
@@ -278,6 +268,7 @@ sub NotificationUpdate {
             \$Param{Body}, \$Param{ContentType}, \$Param{UserID},   \$Param{UserID},
         ],
     );
+
     return 1;
 }
 
