@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# otrs.Scheduler.pl - provides Scheduler Daemon control on Unix like OS
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +10,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -30,31 +31,29 @@ use lib dirname($RealBin) . '/Custom';
 use Getopt::Std;
 use Proc::Daemon;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::Time;
-use Kernel::System::DB;
-use Kernel::System::PID;
+use Kernel::System::Scheduler;
+use Kernel::System::ObjectManager;
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Scheduler;
 
 # defie PID name
 my $PIDName = 'otrs.Scheduler';
 
 # get options
-my %Opts = ();
-getopt( 'hfapw', \%Opts );
+my %Opts;
+getopt( 'apw', \%Opts );
+
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.Scheduler',
+    },
+);
 
 # check if is running on windows
 if ( $^O eq "MSWin32" ) {
     if ( $Opts{w} ) {
 
-        my $ConfigObject = Kernel::Config->new();
-
         # get the scheduler information to restart
-        my $Home      = $ConfigObject->Get('Home');
+        my $Home      = $Kernel::OM->Get('Kernel::Config')->Get('Home');
         my $Scheduler = $Home . '/bin/otrs.Scheduler4win.pl';
 
         # convert Scheduler path to windows format
@@ -129,11 +128,8 @@ elsif ( $Opts{a} && $Opts{a} eq "status" ) {
 # check if a reload request is sent
 elsif ( $Opts{a} && $Opts{a} eq "reload" ) {
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
     # get the process ID
-    my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+    my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
     # no process ID means that is not running
     if ( !%SchedulerPID ) {
@@ -145,8 +141,8 @@ elsif ( $Opts{a} && $Opts{a} eq "reload" ) {
     kill( 1, $SchedulerPID{PID} );
 
     # log daemon stop
-    $CommonObject{LogObject}->Log(
-        Priority => 'debug',
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
+        Priority => 'notice',
         Message  => "Scheduler Daemon reload request! PID $SchedulerPID{PID}",
     );
     exit 0;
@@ -172,7 +168,7 @@ exit 1;
 # Internal
 sub _Help {
     print "otrs.Scheduler.pl - OTRS Scheduler Daemon\n";
-    print "Copyright (C) 2001-2017 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
     print "Usage: otrs.Scheduler.pl -a <ACTION> (start|stop|status|reload) [-f (force)]\n";
     print "       otrs.Scheduler.pl -w 1 (Watchdog mode)\n";
 
@@ -185,37 +181,18 @@ sub _Help {
     return 1;
 }
 
-sub _CommonObjects {
-    my %CommonObject;
-    $CommonObject{ConfigObject} = Kernel::Config->new();
-    $CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-    $CommonObject{LogObject}    = Kernel::System::Log->new(
-        LogPrefix => 'OTRS-otrs.Scheduler',
-        %CommonObject,
-    );
-    $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-    $CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-    $CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
-    $CommonObject{PIDObject}  = Kernel::System::PID->new(%CommonObject);
-    return %CommonObject;
-}
-
 sub _Start {
     my %Param = @_;
 
     {
-
-        # create common objects
-        my %CommonObject = _CommonObjects();
-
         # check if PID is already there
-        my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+        my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
         if (%SchedulerPID) {
 
             # get the PID update time
             my $PIDUpdateTime =
-                $CommonObject{ConfigObject}->Get('Scheduler::PIDUpdateTime') || 60.0;
+                $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::PIDUpdateTime') || 60.0;
 
             # get current time
             my $Time = time();
@@ -256,7 +233,7 @@ sub _Start {
                     "NOTICE: otrs.Scheduler.pl is already running (use '-f' if you want to start it forced)!\n";
 
                 # log daemon already running
-                $CommonObject{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message =>
                         "Scheduler Daemon tried to start but found an already running service!\n",
@@ -269,21 +246,21 @@ sub _Start {
                 "NOTICE: otrs.Scheduler.pl was already running but is starting again (force was used)!\n";
 
             # log daemon forced start
-            $CommonObject{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message  => "Scheduler Daemon is forced to start!",
             );
         }
 
         # get default log path from configuration
-        my $LogPath = $CommonObject{ConfigObject}->Get('Scheduler::LogPath')
-            || $CommonObject{ConfigObject}->Get('Home') . '/var/log';
+        my $LogPath = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::LogPath')
+            || $Kernel::OM->Get('Kernel::Config')->Get('Home') . '/var/log';
 
         # backup old log files
         my $FileStdOut = $LogPath . '/SchedulerOUT.log';
         my $FileStdErr = $LogPath . '/SchedulerERR.log';
         use File::Copy;
-        my $SystemTime = $CommonObject{TimeObject}->SystemTime();
+        my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
         if ( -e $FileStdOut ) {
             move( "$FileStdOut", "$LogPath/SchedulerOUT-$SystemTime.log" );
         }
@@ -292,8 +269,8 @@ sub _Start {
         }
 
         # delete old log files
-        my $DaysToKeep = $CommonObject{ConfigObject}->Get('Scheduler::Log::DaysToKeep') || 10;
-        my $DaysToKeepSystemTime = $CommonObject{TimeObject}->SystemTime() - $DaysToKeep * 24 * 60 * 60;
+        my $DaysToKeep = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::Log::DaysToKeep') || 10;
+        my $DaysToKeepSystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime() - $DaysToKeep * 24 * 60 * 60;
 
         my @LogFiles = glob("$LogPath/*.log");
 
@@ -310,7 +287,7 @@ sub _Start {
             if ( unlink($LogFile) == 0 ) {
 
                 # log old backup file cannot be deleted
-                $CommonObject{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => "Scheduler could not delete old backup file $LogFile! $!",
                 );
@@ -319,16 +296,13 @@ sub _Start {
             else {
 
                 # log old backup file deleted
-                $CommonObject{LogObject}->Log(
-                    Priority => 'debug',
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
+                    Priority => 'notice',
                     Message  => "Scheduler deleted old backup file $LogFile!",
                 );
             }
         }
 
-        # disconnect form DB before daemon, it will prevent DB connection issues, see bug 10492
-        $CommonObject{DBObject}->Disconnect();
-
         # create a new daemon object
         my $Daemon = Proc::Daemon->new();
 
@@ -341,15 +315,12 @@ sub _Start {
         );
     }
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
-    # re-create entire common object again:
+    # re-create database object again:
     #
     # forked scheduler executing RegistrationUpdate tasks using PostgreSQL looses the connection
     #   to the server and this produces errors in SQL statements in different parts of the chain
     #   from Kernel/System/SystemData.pm (trying to list the registration variables) to
-    #   Kernel/Scheduler.pm to bin/otrs.Scheduler.pl (trying to get the PID form the DB).
+    #   Kernel/System/Scheduler.pm to bin/otrs.Scheduler.pl (trying to get the PID form the DB).
     #
     # The results are that the RegistrationUpdate task is not executed and the scheduler stops.
     #
@@ -358,25 +329,26 @@ sub _Start {
     #     DBD::Pg::st execute failed: lost synchronization with server: got message type "s"
     #     DBD::Pg::st execute failed: lost synchronization with server: got message type "e"
     #
-    # It has been found that just creating the entire common object again either at this point
-    #     or within the "main loop" works around the problem; re-creating just the DBObject does not
-    #     work correctly.
-    %CommonObject = _CommonObjects();
+    # It has been found that discarding the database object, create it again and invoking Connect()
+    #    this means a second connection fixes this problem, but just creating the database object
+    #    not.
+    $Kernel::OM->ObjectsDiscard();
+    $Kernel::OM->Get('Kernel::System::DB')->Connect();
 
     # if start is forced, be sure to remove any PID from any host
     my $Force = $Param{Force} ? 1 : '';
 
     # create new PID on the Database
-    $CommonObject{PIDObject}->PIDCreate(
+    $Kernel::OM->Get('Kernel::System::PID')->PIDCreate(
         Name  => $PIDName,
         Force => $Force,
     );
 
     # get the process ID
-    my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+    my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
     # set run directory for PID File
-    my $Home    = $CommonObject{ConfigObject}->Get('Home');
+    my $Home    = $Kernel::OM->Get('Kernel::Config')->Get('Home');
     my $RunDir  = $Home . '/var/run';
     my $PIDFile = "$RunDir/scheduler.pid";
 
@@ -411,7 +383,7 @@ sub _Start {
     }
 
     # Log daemon start up
-    $CommonObject{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'notice',
         Message  => "Scheduler Daemon start! PID $SchedulerPID{PID}",
     );
@@ -429,21 +401,21 @@ sub _Start {
     # when get a HUP signal, set HUP flag
     local $SIG{HUP} = sub { $Hangup = 1 };
 
-    my $SleepTime = $CommonObject{ConfigObject}->Get('Scheduler::SleepTime') || 1;
+    my $SleepTime = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::SleepTime') || 1;
 
-    my $RestartAfterSeconds = $CommonObject{ConfigObject}->Get('Scheduler::RestartAfterSeconds')
+    my $RestartAfterSeconds = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::RestartAfterSeconds')
         || ( 60 * 60 * 24 );    # default 1 day
 
-    my $StartTime = $CommonObject{TimeObject}->SystemTime();
+    my $StartTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
     # get config checksum
-    my $InitConfigMD5 = $CommonObject{ConfigObject}->ConfigChecksum();
+    my $InitConfigMD5 = $Kernel::OM->Get('Kernel::Config')->ConfigChecksum();
 
     # main loop
     while (1) {
 
         # get the process ID
-        my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+        my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
         # check if process ID was deleted from DB
         if ( !%SchedulerPID ) {
@@ -468,7 +440,7 @@ sub _Start {
         }
 
         # get config checksum
-        my $CurrConfigMD5 = $CommonObject{ConfigObject}->ConfigChecksum();
+        my $CurrConfigMD5 = $Kernel::OM->Get('Kernel::Config')->ConfigChecksum();
 
         # check if checksum changed and restart
         if ( $InitConfigMD5 ne $CurrConfigMD5 ) {
@@ -498,10 +470,10 @@ sub _Start {
         }
 
         # Call Scheduler
-        my $SchedulerObject = Kernel::Scheduler->new(%CommonObject);
+        my $SchedulerObject = Kernel::System::Scheduler->new();
         $SchedulerObject->Run();
 
-        my $CurrentTime = $CommonObject{TimeObject}->SystemTime();
+        my $CurrentTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
         # The Scheduler needs to be restarted from time to time because
         #   of memory leaks in some external perl modules.
@@ -524,11 +496,8 @@ sub _Start {
 sub _Stop {
     my %Param = @_;
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
     # get the process ID
-    my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+    my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
     my $ExitCode = 0;
 
@@ -542,7 +511,7 @@ sub _Stop {
     # send interrupt signal to the process ID to stop it
     kill( 2, $SchedulerPID{PID} );
 
-    $CommonObject{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'notice',
         Message  => "Scheduler Daemon Stop! PID $SchedulerPID{PID}",
     );
@@ -552,14 +521,14 @@ sub _Stop {
     if ( $Param{Force} ) {
 
         # delete process ID lock
-        my $PIDDelSuccess = $CommonObject{PIDObject}->PIDDelete(
+        my $PIDDelSuccess = $Kernel::OM->Get('Kernel::System::PID')->PIDDelete(
             Name  => $SchedulerPID{Name},
             Force => 1,
         );
 
         # log daemon stop
         if ( !$PIDDelSuccess ) {
-            $CommonObject{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message =>
                     "Process could not be deleted from process table! PID $SchedulerPID{PID}",
@@ -569,13 +538,13 @@ sub _Stop {
         }
 
         # delete PID file
-        my $Home    = $CommonObject{ConfigObject}->Get('Home');
+        my $Home    = $Kernel::OM->Get('Kernel::Config')->Get('Home');
         my $PIDFile = $Home . '/var/run/scheduler.pid';
 
         if ( unlink($PIDFile) == 0 ) {
 
             # log PID file cannot be deleted
-            $CommonObject{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Scheduler could not delete PID file:'$PIDFile'! $!",
             );
@@ -583,7 +552,7 @@ sub _Stop {
     }
 
     # get the sleeptime from config
-    my $SleepTime = $CommonObject{ConfigObject}->Get('Scheduler::SleepTime') || 1;
+    my $SleepTime = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::SleepTime') || 1;
 
     # we want to add 2 seconds to wait until other processes wake up after their own sleep time
     $SleepTime += 2;
@@ -596,11 +565,8 @@ sub _Stop {
 sub _Status {
     my %Param = @_;
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
     # get the process ID
-    my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+    my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
     # no process ID means that is not running
     if ( !%SchedulerPID ) {
@@ -608,8 +574,8 @@ sub _Status {
     }
 
     # log daemon stop
-    $CommonObject{LogObject}->Log(
-        Priority => 'debug',
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
+        Priority => 'notice',
         Message  => "Scheduler Daemon status request! PID $SchedulerPID{PID}",
     );
 
@@ -630,27 +596,24 @@ sub _Status {
 sub _AutoRestart {
     my (%Param) = @_;
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
     # get the process ID
-    my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+    my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
     # Log daemon start-up
-    $CommonObject{LogObject}->Log(
+    $Kernel::OM->Get('Kernel::System::Log')->Log(
         Priority => 'notice',
         Message  => $Param{Message} || 'Unknown reason to restart',
     );
 
     # delete process ID lock
-    my $PIDDelSuccess = $CommonObject{PIDObject}->PIDDelete(
+    my $PIDDelSuccess = $Kernel::OM->Get('Kernel::System::PID')->PIDDelete(
         Name  => $SchedulerPID{Name},
         Force => 1,
     );
 
     my $ExitCode;
     if ( !$PIDDelSuccess ) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message =>
                 "Could not remove Scheduler PID $SchedulerPID{PID} from database to prepare Scheduler restart, exiting.",
@@ -659,13 +622,13 @@ sub _AutoRestart {
         return $ExitCode;
     }
 
-    my $Home      = $CommonObject{ConfigObject}->Get('Home');
+    my $Home      = $Kernel::OM->Get('Kernel::Config')->Get('Home');
     my $Scheduler = $Home . '/bin/otrs.Scheduler.pl';
 
     my $StartExitCode = system("$Scheduler -a start");
 
     if ($StartExitCode) {
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Could not start-up new Scheduler instance.",
         );
@@ -681,13 +644,10 @@ sub _AutoRestart {
 sub _AutoStop {
     my (%Param) = @_;
 
-    # create common objects
-    my %CommonObject = _CommonObjects();
-
     if ( $Param{Message} ) {
 
         # log error
-        $CommonObject{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $Param{Message},
         );
@@ -697,17 +657,17 @@ sub _AutoStop {
     if ( $Param{DeletePID} ) {
 
         # get the process ID
-        my %SchedulerPID = $CommonObject{PIDObject}->PIDGet( Name => $PIDName );
+        my %SchedulerPID = $Kernel::OM->Get('Kernel::System::PID')->PIDGet( Name => $PIDName );
 
         # send interrupt signal to the process ID to stop it
         kill( 2, $SchedulerPID{PID} );
 
         # delete process ID lock
         # scheduler should not delete PIDs from other hosts at this point
-        my $PIDDelSuccess = $CommonObject{PIDObject}->PIDDelete( Name => $SchedulerPID{Name} );
+        my $PIDDelSuccess = $Kernel::OM->Get('Kernel::System::PID')->PIDDelete( Name => $SchedulerPID{Name} );
 
         # get the sleeptime from config
-        my $SleepTime = $CommonObject{ConfigObject}->Get('Scheduler::SleepTime') || 1;
+        my $SleepTime = $Kernel::OM->Get('Kernel::Config')->Get('Scheduler::SleepTime') || 1;
 
         # we want to add 2 seconds to wait until other processes wake up after their own sleep time
         $SleepTime += 2;
@@ -716,7 +676,7 @@ sub _AutoStop {
 
         # log daemon stop
         if ( !$PIDDelSuccess ) {
-            $CommonObject{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message =>
                     "Process could not be deleted from process table! PID $SchedulerPID{PID}",
@@ -726,7 +686,7 @@ sub _AutoStop {
         }
 
         #delete PID file
-        my $Home    = $CommonObject{ConfigObject}->Get('Home');
+        my $Home    = $Kernel::OM->Get('Kernel::Config')->Get('Home');
         my $PIDFile = $Home . '/var/run/scheduler.pid';
 
         # check if the PID file exists
@@ -738,7 +698,7 @@ sub _AutoStop {
             if ( unlink($PIDFile) == 0 ) {
 
                 # log PID file cannot be deleted
-                $CommonObject{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'error',
                     Message  => "Scheduler could not delete PID file:'$PIDFile'! $!",
                 );
@@ -756,32 +716,8 @@ sub _AutoStop {
 sub _WatchDog {
     my %Param = @_;
 
-    # create common object
-    my %CommonObject;
-    $CommonObject{ConfigObject} = Kernel::Config->new();
-    $CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-    $CommonObject{LogObject}    = Kernel::System::Log->new(
-        LogPrefix => 'OTRS-otrs.Scheduler-Watchdog',
-        %CommonObject,
-    );
-    $CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-    $CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-    $CommonObject{DBObject}   = Kernel::System::DB->new(
-        %CommonObject,
-        AutoConnectNo => 1,
-    );
-
     my $ExitCode = 0;
 
-    # check if OTRS can connect to the DB
-    if ( !$CommonObject{DBObject}->Connect() ) {
-        $CommonObject{LogObject}->Log(
-            Priority => 'notice',
-            Message  => "Database is not ready!",
-        );
-        return $ExitCode;
-    }
-
     my $ProcessID = _Status();
 
     if ( !$ProcessID ) {
@@ -795,7 +731,7 @@ sub _WatchDog {
             $ExitCode = _Start();
         }
         else {
-            $CommonObject{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message =>
                     'Scheduler was forced to stop but it is still registered, can not continue',
@@ -804,7 +740,7 @@ sub _WatchDog {
         }
     }
 
-    # if there is a $ProcessID and it is not -1 then it means that the scheduler is running, nothing to
-    #   do here
+    # if there is a $ProcessID and it is not -1 then it means that the scheduler is running,
+    # then nothing to do here
     return $ExitCode;
 }
